//
//  AccessoriesTableViewController.swift
//  HomeKitExample
//
//  Created by Scott Lee on 2016. 10. 20..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import UIKit
import HomeKit

class AccessoriesTableViewController: UITableViewController, HMAccessoryBrowserDelegate, HMHomeManagerDelegate {
    let hkManager = HMHomeManager()
    let hkBrowser = HMAccessoryBrowser()
    var accessories = [HMAccessory]()
    var currentHome: HMHome?
    var currentRoom: HMRoom?
    
    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return accessories.count
    }
    
    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "AccessoryCell", for: indexPath)
        let accessory = accessories[indexPath.row] as HMAccessory
        
        cell.textLabel?.text = accessory.name
        
        if accessory.room != nil {
            cell.detailTextLabel?.text = "Detail >"
        } else {
            cell.detailTextLabel?.text = "Not Paired"
        }
        
        let longGR = UILongPressGestureRecognizer(target: self, action: #selector(removeAccessory))
        cell.addGestureRecognizer(longGR)
        
        return cell
    }
    
    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let accessory = accessories[indexPath.row] as HMAccessory
        
        if currentRoom != nil {
            self.currentHome!.addAccessory(accessory, completionHandler: { (error) -> Void in
                if error != nil {
                    print("액세서리 연결 실패 \(error!.localizedDescription)")
                } else {
                    self.currentHome!.assignAccessory(accessory, to: self.currentRoom!, completionHandler: {
                        (error) -> Void in
                        if error != nil {
                            print("액세서리 등록 실패 \(error!.localizedDescription)")
                        } else {
                            self.stopSearching()
                            self.accessoryBrowser(self.hkBrowser, didFindNewAccessory: accessory)
                            tableView.reloadData()
                        }
                    })
                }
            })
        }
    }
    
    override func shouldPerformSegue(withIdentifier identifier: String, sender: Any?) -> Bool {
        let pointInTable: CGPoint = (sender! as AnyObject).convert((sender! as AnyObject).bounds.origin, to: self.tableView)
        if let indexPath = tableView.indexPathForRow(at: pointInTable) {
            let accessory = self.accessories[indexPath.row] as HMAccessory
            
            if accessory.room != nil {
                return true
            }
        }
        
        return false
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        if let tableViewController = segue.destination as? CharacteristicsTableViewController {
            if let indexPath = tableView.indexPathForSelectedRow {
                tableViewController.accessory = self.accessories[indexPath.row]
            }
        }
    }
    
    required init(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)!
        hkManager.delegate = self
        
        title = "Now Searching"
        hkBrowser.delegate = self
        hkBrowser.startSearchingForNewAccessories()
        
        Timer.scheduledTimer(timeInterval: 15.0, target: self, selector: #selector(stopSearching), userInfo: nil, repeats: false)
        
        title = "Device List"
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Search", style: UIBarButtonItemStyle.plain, target: self, action: #selector(startSearching))
    }
    
    func startSearching() {
        title = "Now Searching"
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Stop", style: UIBarButtonItemStyle.plain, target: self, action: #selector(stopSearching))
        hkBrowser.startSearchingForNewAccessories()
        
        Timer.scheduledTimer(timeInterval: 15.0, target: self, selector: #selector(stopSearching), userInfo: nil, repeats: false)
    }
    
    func stopSearching() {
        title = "Device List"
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Search", style: UIBarButtonItemStyle.plain, target: self, action: #selector(startSearching))
        hkBrowser.stopSearchingForNewAccessories()
    }
    
    func accessoryBrowser(_ browser: HMAccessoryBrowser, didFindNewAccessory accessory: HMAccessory) {
        accessories.append(accessory)
        tableView.reloadData()
    }
    
    func accessoryBrowser(_ browser: HMAccessoryBrowser, didRemoveNewAccessory deletedAccessory: HMAccessory) {
        var index = 0
        for accessory in accessories {
            if accessory.name == deletedAccessory.name {
                accessories.remove(at: index)
                break;
            }
            index += 1
        }
        tableView.reloadData()
    }
    
    func getCurrentAccessories() {
        self.accessories = [HMAccessory]()

        if let accessories = self.currentRoom?.accessories {
            for accessory in accessories {
                self.accessories.append(accessory)
            }
        }
    }
    
    func homeManagerDidUpdateHomes(_ hkManager: HMHomeManager) {
        if let currentHome = hkManager.primaryHome {
            self.currentHome = currentHome
            self.currentRoom = self.currentHome?.rooms.first
        } else {
            makePrimaryHome()
        }
        
        getCurrentAccessories()

        tableView.reloadData()
    }
    
    private func makePrimaryHome() {
        hkManager.addHome(withName: "My Home", completionHandler: { (primaryHome, error) -> Void in
            if error != nil {
                print("홈 생성 에러 \(error!.localizedDescription)")
            } else {
                primaryHome!.addRoom(withName: "My Room", completionHandler: { (primaryRoom, error) -> Void in
                    if error != nil {
                        print("룸 생성 에러 \(error!.localizedDescription)")
                    }
                })
                
                self.hkManager.updatePrimaryHome(primaryHome!, completionHandler: { (error) -> Void in
                    if error != nil {
                        print("기본 홈 설정 실패 \(error!.localizedDescription)")
                    } else {
                        self.currentHome = primaryHome
                        self.currentRoom = self.currentHome?.rooms.first
                    }
                })
            }
        })
    }
    
    func removeAccessory(sender: UIGestureRecognizer) {
        let point = sender.location(in: tableView)
        
        if let indexPath = tableView.indexPathForRow(at: point) {
            if let accessory: HMAccessory = accessories[indexPath.row] {
                if accessory.room != nil {
                    currentHome!.removeAccessory(accessory, completionHandler: {
                        (error) -> Void in
                        if error != nil {
                            print("액세서리 제거 실패 \(error!.localizedDescription)")
                        } else  {
                            print("액세서리 제거 성공")
                            self.accessoryBrowser(self.hkBrowser, didRemoveNewAccessory: accessory)
                            self.tableView.reloadData()
                        }
                    })
                }
            }
        }
        
        tableView.reloadData()
    }
}
