//
//  AddBodyInfoTableViewController.swift
//  HealthKitExample
//
//  Created by Scott Lee on 2016. 10. 22..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import UIKit
import HealthKit

class AddBodyInfoTableViewController: UITableViewController {
    @IBOutlet weak var labelHeight: UILabel!
    @IBOutlet weak var labelWeight: UILabel!
    @IBOutlet weak var labelBFP: UILabel!
    @IBOutlet weak var labelLBM: UILabel!
    @IBOutlet weak var labelBMI: UILabel!
    @IBOutlet weak var cellHeight: UITableViewCell!
    @IBOutlet weak var cellWeight: UITableViewCell!
    @IBOutlet weak var cellBFP: UITableViewCell!

    let hkStore: HKHealthStore = HKHealthStore()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        navigationItem.title = "Add Body Info"
        let saveBtn : UIBarButtonItem = UIBarButtonItem(title: "Save", style: .plain, target: self, action: #selector(saveBodyInfo))
        
        self.navigationItem.rightBarButtonItem = saveBtn
    }
    
    override func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        switch indexPath.row {
        case 0:
            showAlert("Height", msg: "Insert your Height.", label: labelHeight, unit: "cm")
            break
        case 1:
            showAlert("Weight", msg: "Insert your Weight.", label: labelWeight, unit: "kg")
            break
        case 2:
            showAlert("Body Fat", msg: "Insert your Body Fat Percentage", label: labelBFP, unit: "%")
            break
        default: break
        }
    }
    
    func showAlert(_ title:String, msg:String, label:UILabel, unit:String) {
        let alert = UIAlertController(title: title, message: msg + " Unit : " + unit, preferredStyle: .alert)
        
        alert.addTextField(configurationHandler: { (textField) -> Void in })
        alert.addAction(UIAlertAction(title: "OK", style: .default, handler: { (action) -> Void in
            let textField = alert.textFields![0] as UITextField
            label.text = textField.text! + " " + unit
            self.calcData()
        }))
        
        self.present(alert, animated: true, completion: nil)
    }
    
    func calcData() {
        let height = getNumber(label: labelHeight)
        let weight = getNumber(label: labelWeight)
        let bfp = getNumber(label: labelBFP)
        
        if height > 0 && weight > 0 && bfp > 0 {
            labelBMI.text =  String(format: "%.2f BMI", weight / pow((height / 100), 2))
            labelLBM.text = String(format: "%.2f kg", weight * ((100 - bfp) / 100) )
        } else {
            labelBMI.text = "0 BMI"
            labelLBM.text = "0 kg"
        }
    }
    
    func getNumber(label:UILabel) -> Double {
        var arr = label.text!.characters.split {$0 == " "}.map(String.init)
        
        if let number = NumberFormatter().number(from: arr[0]) {
            return number.doubleValue
        }
        
        return 0.0
    }
    
    func saveBodyInfo() {
        let currentDate = Date()
        
        let heightSample = HKQuantitySample(type: HKQuantityType.quantityType(forIdentifier: HKQuantityTypeIdentifier.height)!, quantity: HKQuantity(unit: HKUnit(from: "cm"), doubleValue: getNumber(label: labelHeight)), start: currentDate, end: currentDate)
        let weightSample = HKQuantitySample(type: HKQuantityType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)!, quantity: HKQuantity(unit: HKUnit(from: "kg"), doubleValue: getNumber(label: labelWeight)), start: currentDate, end: currentDate)
        let lbmSample = HKQuantitySample(type: HKQuantityType.quantityType(forIdentifier: HKQuantityTypeIdentifier.leanBodyMass)!, quantity: HKQuantity(unit: HKUnit(from: "kg"), doubleValue: getNumber(label: labelLBM)), start: currentDate, end: currentDate)
        let bmiSample = HKQuantitySample(type: HKQuantityType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMassIndex)!, quantity: HKQuantity(unit: HKUnit.count(), doubleValue: getNumber(label: labelBMI)), start: currentDate, end: currentDate)
        let bfpSample = HKQuantitySample(type: HKQuantityType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyFatPercentage)!, quantity: HKQuantity(unit: HKUnit.percent(), doubleValue: getNumber(label: labelBFP) / 100), start: currentDate, end: currentDate)
        
        hkStore.save([heightSample, weightSample, bfpSample, lbmSample, bmiSample]) { (success, error) -> Void in
            if success {
                print("정보 저장 성공")
            } else {
                print("정보 저장 실패")
            }
        }
        
        navigationController!.popViewController(animated: true)
    }
}

