//
//  ViewController.swift
//  HealthKitExample
//
//  Created by Scott Lee on 2016. 10. 20..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import UIKit
import HealthKit

class ViewController: UITableViewController {
    let hkStore: HKHealthStore = HKHealthStore()
    var hkAvailable = false
    
    @IBOutlet weak var labelBirthday: UILabel!
    @IBOutlet weak var labelGender: UILabel!
    @IBOutlet weak var labelBloodtype: UILabel!
    @IBOutlet weak var labelSkintype: UILabel!

    override func viewDidLoad() {
        super.viewDidLoad()
        
        if !hkAvailable {
            getAuth()
        }
    }
    
    override func viewDidAppear(_ animated: Bool) {
        getPersonalData()
    }
    
    func getPersonalData() {
        do {
            let biologicalSex = try hkStore.biologicalSex()
            switch(biologicalSex.biologicalSex) {
            case .male:
                labelGender.text = "Male"
                break
            case .female:
                labelGender.text = "Female"
                break
            case .notSet:
                labelGender.text = "Not Set"
                break
            default:
                labelGender.text = "Other"
                break
            }
        } catch {
            print("성별 읽기 실패")
        }
        
        do {
            let bloodType = try hkStore.bloodType()
            switch(bloodType.bloodType) {
            case .aPositive:
                labelBloodtype.text = "Rh+ A"
                break
            case .aNegative:
                labelBloodtype.text = "Rh- A"
                break
            case .bPositive:
                labelBloodtype.text = "Rh+ B"
                break
            case .bNegative:
                labelBloodtype.text = "Rh- B"
                break
            case .abPositive:
                labelBloodtype.text = "Rh+ AB"
                break
            case .abNegative:
                labelBloodtype.text = "Rh- AB"
                break
            case .oPositive:
                labelBloodtype.text = "Rh+ O"
                break
            case .oNegative:
                labelBloodtype.text = "Rh- O"
                break
            default:
                labelBloodtype.text = "Not Set"
                break
            }
        } catch {
            print("혈액형 읽기 실패")
        }
        
        do {
            let fitzpatrickType = try hkStore.fitzpatrickSkinType()
            switch(fitzpatrickType.skinType) {
            case .I:
                labelSkintype.text = "I"
                break
            case .II:
                labelSkintype.text = "II"
                break
            case .III:
                labelSkintype.text = "III"
                break
            case .IV:
                labelSkintype.text = "IV"
                break
            case .V:
                labelSkintype.text = "V"
                break
            case .VI:
                labelSkintype.text = "VI"
                break;
            default:
                labelSkintype.text = "Not Set"
                break
            }
        } catch {
            print("피부 타입 읽기 실패")
        }
        
        do {
            let birthDay = try hkStore.dateOfBirthComponents()
            let dateFormatter = DateFormatter()
            dateFormatter.dateStyle = DateFormatter.Style.medium
            labelBirthday.text = dateFormatter.string(from: birthDay.date!)
        } catch {
            print("생일 읽기 실패")
        }
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    func getAuth() {
        let hkWriteData = Set(arrayLiteral:
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.height)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyFatPercentage)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.leanBodyMass)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMassIndex)!
        )
        
        let hkReadData = Set(arrayLiteral:
            HKObjectType.characteristicType(forIdentifier: HKCharacteristicTypeIdentifier.dateOfBirth)!,
            HKObjectType.characteristicType(forIdentifier: HKCharacteristicTypeIdentifier.biologicalSex)!,
            HKObjectType.characteristicType(forIdentifier: HKCharacteristicTypeIdentifier.bloodType)!,
            HKObjectType.characteristicType(forIdentifier: HKCharacteristicTypeIdentifier.fitzpatrickSkinType)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.height)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMass)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyFatPercentage)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.leanBodyMass)!,
            HKObjectType.quantityType(forIdentifier: HKQuantityTypeIdentifier.bodyMassIndex)!
        )
        
        if !HKHealthStore.isHealthDataAvailable() {
            hkAvailable = false
        }
        
        hkStore.requestAuthorization(toShare: hkWriteData, read: hkReadData) { (success, error) -> Void in
            if success {
                self.hkAvailable = true
            } else if error != nil {
                self.hkAvailable = false
                print("HealthKit 권한 획득 실패 \(error!.localizedDescription)")
            }
        }
    }
}

