//
//  InterfaceController.swift
//  WatchKitExample WatchKit Extension
//
//  Created by Scott Lee on 2016. 10. 25..
//  Copyright © 2016년 Studio G.B.U. All rights reserved.
//

import WatchKit
import Foundation


class InterfaceController: WKInterfaceController {
    @IBOutlet var informationLabel: WKInterfaceLabel!
    @IBOutlet var workoutTimer: WKInterfaceTimer!

    var workoutCount: Int = 1
    var setCount: Int = 1
    var isWorkout: Bool = true
    var timer: Timer!
    
    override func awake(withContext context: Any?) {
        super.awake(withContext: context)
        
        informationLabel.setText("Select Start Menu")
    }
    
    func startTimer() {
        informationLabel.setText("Set \(setCount) - Workout \(workoutCount)")

        if isWorkout {
            timer = Timer.scheduledTimer(timeInterval: 20, target: self, selector: #selector(doHaptic), userInfo: nil, repeats: false)
            let finishTime = Date(timeIntervalSinceNow: 20)
            workoutTimer.setDate(finishTime)
            workoutTimer.start()
        } else {
            timer = Timer.scheduledTimer(timeInterval: 10, target: self, selector: #selector(doHaptic), userInfo: nil, repeats: false)
            let finishTime = Date(timeIntervalSinceNow: 10)
            workoutTimer.setDate(finishTime)
            workoutTimer.start()
        }
    }
    
    func doHaptic() {
        let device = WKInterfaceDevice.current()
        device.play(.notification)
        isWorkout = !isWorkout

        if isWorkout {
            workoutCount = (workoutCount + 1) % 5
            
            if workoutCount == 0 {
                workoutCount = 1
            }
            
            if workoutCount == 1 {
                setCount += 1
            }
        }
        
        self.startTimer()
    }
    
    @IBAction func menuStart() {
        self.workoutCount = 1
        self.setCount = 1
        self.isWorkout = true
        
        self.startTimer()
    }
    
    
    @IBAction func menuStop() {
        workoutTimer.stop()
        timer.invalidate()
    }
    
    override func willActivate() {
        // This method is called when watch view controller is about to be visible to user
        super.willActivate()
    }
    
    override func didDeactivate() {
        // This method is called when watch view controller is no longer visible
        super.didDeactivate()
    }

}
